From: Linus Torvalds Date: Tue, 31 Jan 2006 22:07:30 GMT Subject: Re: [PATCH 3/3] Use struct tree in diff-tree Message-ID: In-Reply-To: <7virs0uma8.fsf@assigned-by-dhcp.cox.net> On Tue, 31 Jan 2006, Junio C Hamano wrote: > > The one to git-tar-tree I've already applied, mostly because I > was not careful enough and especially I did not care enough > about performance of that program. On my slow machine the tip > of kernel before you came back takes 9.2 seconds wallclock as > opposed to 8.7 seconds to tar up, so the patch degrades the > performance by about 5%. Maybe we would want to revert that one > as well. Hmm. Rather than revert it outright, it might be better to make it use the nicer parsing functions and "struct tree_desc". It shouldn't look _that_ different from the "struct tree" version: instead of doing item = item->next; it would do update_tree_entry(tree); instead. Give me a minute, I'll send you patches. Linus